FileName      = 'glucose_insulin_parameters_m';              % M-file describing the model structure.
Order         = [1 2 5];                                     % Model orders [ny nu nx].

Parameters    = [1.81*60; 2.45*60; 0.0101*1000/60];          % Initial parameters. Np = 3.
                                                             % [T_xi, T_m, K_i]
InitialStates = [1; 1; 1; 4.5; 4.5;];                        % Initial initial states. Nx = 5.
                                                             % [I X S G Y]
Ts            = 0;                                           % Time-continuous system.

%creating a nonlinear model to be identified. 
themodel = idnlgrey(FileName, Order, Parameters, InitialStates, Ts, 'Name', 'Blood glucose model');

%setting model input and output names and units
set(themodel, 'InputName', {'Insulin dosage', 'Meal glucose contribution'}, 'InputUnit', {'mikroU/min', 'mmol/min'}, 'OutputName', 'Blood glucose', 'OutputUnit', 'mmol/L', 'TimeUnit', 'min');
size(themodel)

%setting names and units of the initial states
setinit(themodel, 'Name', {'Insulin' 'X' 'S' 'Plasma glucose' 'Blood glucose'});
setinit(themodel, 'Unit', {'mikroU/min' 'U/min' 'U/min' 'mmol/L' 'mmol/L'});

%setting names and units of the model parameters
setpar(themodel, 'Name', {'T_xi' 'T_m' 'K_i'});
setpar(themodel, 'Unit', {'min' ,'min' 'mL/min'});


%comparing the model to the measured data without parameter estimation
themodel.Algorithm.SimulationOptions.AbsTol = 1e-5;
themodel.Algorithm.SimulationOptions.RelTol = 1e-6;
figure;
compare(z, themodel);

% Estimate the initial states.
setinit(themodel, 'Fixed', {false false false false false});   % Estimate the initial state.
themodel = pem(z, themodel, 'Trace', 'Full', 'MaxIter', 20);
themodel.EstimationInfo
figure;
compare(z, themodel);
