FileName      = 'glucose_online_m';                          % File describing the model structure.
Order         = [1 2 5];                                     % Model orders [ny nu nx].

Parameters    = 0.0481/60;                                   % Initial parameters. Np = 1. 
                                                             % K_i   

InitialStates = [1; 1; 1; 7; 7];                             % Initial initial states. Nx = 5.
                                                             % [I X S G Y]
Ts            = 0;                                           % Time-continuous system.

themodel = idnlgrey(FileName, Order, Parameters, InitialStates, Ts, 'Name', 'Blood glucose model');

set(themodel, 'InputName', {'Insulin dosage', 'Meal glucose contribution'}, 'InputUnit', {'mikroU/min', 'mmol/min'}, 'OutputName', 'Blood glucose', 'OutputUnit', 'mmol/L', 'TimeUnit', 'min');
size(themodel)



setinit(themodel, 'Name', {'Insulin' 'X' 'S' 'Plasma glucose' 'Blood glucose'});
setinit(themodel, 'Unit', {'mikroU/min' 'U/min' 'U/min' 'mmol/L' 'mmol/L'});
setpar(themodel, 'Name', {'K_is'});
setpar(themodel, 'Unit', {'mL/min'});



themodel.Algorithm.SimulationOptions.AbsTol = 1e-5;
themodel.Algorithm.SimulationOptions.RelTol = 1e-6;
%figure;
%compare(z, themodel);


setinit(themodel, 'Fixed', {false false false false false});   % Estimate the initial state.
themodel = pem(z, themodel, 'Trace', 'Full', 'MaxIter', 20);
themodel.EstimationInfo
%figure;
%compare(z, themodel);

